trace_testing

package
v0.0.0-...-a488fd3 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Dec 10, 2024 License: BSD-3-Clause Imports: 12 Imported by: 0

Documentation

Index

Constants

const (
	ServiceNameEnvVar = "GO_TEST_TRACE_SERVICE_NAME"

	// SkipperNetworkEnvVar is the environment variable used to pass the listener network
	SkipperNetworkEnvVar = "GO_TEST_TRACE_SKIPPER_NETWORK"

	// SkipperAddressEnvVar is the environment variable used to pass the listener address
	SkipperAddressEnvVar = "GO_TEST_TRACE_SKIPPER_ADDRESS"

	CarrierEnvVarPrefix = "GO_TEST_TRACE_CARRIER_"
)

Variables

This section is empty.

Functions

This section is empty.

Types

type BasicT

type BasicT interface {
	testing.TB
	Deadline() (deadline time.Time, ok bool)
	Parallel()
	Run(name string, f func(t *testing.T)) bool
}

type T

type T interface {
	testing.TB
	Deadline() (deadline time.Time, ok bool)
	Parallel()
	Context() context.Context
	WithContext(ctx context.Context) T
	Run(name string, f func(t T)) bool
}

func WithTracing

func WithTracing(t BasicT) T

Jump to